from setuptools import setup

setup(name='ajd-distributions',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['ajd_distributions'],
      author = 'Arkojyoti Das',
      author_email = 'arkojyotidas18@gmail.com',
      zip_safe=False)
